==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/ServerAddressByClientCIDRBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ServerAddressByClientCIDRBuilder extends ServerAddressByClientCIDRFluentImpl<ServerAddressByClientCIDRBuilder> implements VisitableBuilder<ServerAddressByClientCIDR,ServerAddressByClientCIDRBuilder>{
  public ServerAddressByClientCIDRBuilder() {
    this(false);
  }
  public ServerAddressByClientCIDRBuilder(Boolean validationEnabled) {
    this(new ServerAddressByClientCIDR(), validationEnabled);
  }
  public ServerAddressByClientCIDRBuilder(ServerAddressByClientCIDRFluent<?> fluent) {
    this(fluent, false);
  }
  public ServerAddressByClientCIDRBuilder(ServerAddressByClientCIDRFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ServerAddressByClientCIDR(), validationEnabled);
  }
  public ServerAddressByClientCIDRBuilder(ServerAddressByClientCIDRFluent<?> fluent,ServerAddressByClientCIDR instance) {
    this(fluent, instance, false);
  }
  public ServerAddressByClientCIDRBuilder(ServerAddressByClientCIDRFluent<?> fluent,ServerAddressByClientCIDR instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withClientCIDR(instance.getClientCIDR());
      fluent.withServerAddress(instance.getServerAddress());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ServerAddressByClientCIDRBuilder(ServerAddressByClientCIDR instance) {
    this(instance,false);
  }
  public ServerAddressByClientCIDRBuilder(ServerAddressByClientCIDR instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withClientCIDR(instance.getClientCIDR());
      this.withServerAddress(instance.getServerAddress());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ServerAddressByClientCIDRFluent<?> fluent;
  Boolean validationEnabled;
  public ServerAddressByClientCIDR build() {
    ServerAddressByClientCIDR buildable = new ServerAddressByClientCIDR(fluent.getClientCIDR(),fluent.getServerAddress());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/ServerAddressByClientCIDRBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ServerAddressByClientCIDRBuilder extends ServerAddressByClientCIDRFluent<ServerAddressByClientCIDRBuilder> implements VisitableBuilder<ServerAddressByClientCIDR,ServerAddressByClientCIDRBuilder>{
  public ServerAddressByClientCIDRBuilder() {
    this(false);
  }
  public ServerAddressByClientCIDRBuilder(Boolean validationEnabled) {
    this(new ServerAddressByClientCIDR(), validationEnabled);
  }
  public ServerAddressByClientCIDRBuilder(ServerAddressByClientCIDRFluent<?> fluent) {
    this(fluent, false);
  }
  public ServerAddressByClientCIDRBuilder(ServerAddressByClientCIDRFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ServerAddressByClientCIDR(), validationEnabled);
  }
  public ServerAddressByClientCIDRBuilder(ServerAddressByClientCIDRFluent<?> fluent,ServerAddressByClientCIDR instance) {
    this(fluent, instance, false);
  }
  public ServerAddressByClientCIDRBuilder(ServerAddressByClientCIDRFluent<?> fluent,ServerAddressByClientCIDR instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ServerAddressByClientCIDR());

    if (instance != null) {
      fluent.withClientCIDR(instance.getClientCIDR());
      fluent.withServerAddress(instance.getServerAddress());
      fluent.withClientCIDR(instance.getClientCIDR());
      fluent.withServerAddress(instance.getServerAddress());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ServerAddressByClientCIDRBuilder(ServerAddressByClientCIDR instance) {
    this(instance,false);
  }
  public ServerAddressByClientCIDRBuilder(ServerAddressByClientCIDR instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ServerAddressByClientCIDR());

    if (instance != null) {
      this.withClientCIDR(instance.getClientCIDR());
      this.withServerAddress(instance.getServerAddress());
      this.withClientCIDR(instance.getClientCIDR());
      this.withServerAddress(instance.getServerAddress());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ServerAddressByClientCIDRFluent<?> fluent;
  Boolean validationEnabled;
  public ServerAddressByClientCIDR build() {
    ServerAddressByClientCIDR buildable = new ServerAddressByClientCIDR(fluent.getClientCIDR(),fluent.getServerAddress());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
